# blroots
# Copyright (C) blroots blext Project Contributors
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.	If not, see <http://www.gnu.org/licenses/>.

"""Manages the registration of Blender classes, including delayed registrations that require access to Python dependencies.

Attributes:
	_REGISTERED_HANDLERS: Addon handlers currently registered by this addon.
"""

from collections import defaultdict

from blroots import typ as bltyp
from blroots.utils import bl_logger
from blroots.utils.bl_handlers import BLHandlers

log = bl_logger.get(__name__)

####################
# - Globals
####################
_REGISTERED_HANDLERS: defaultdict[bltyp.BLExtName, BLHandlers | None] = defaultdict(lambda: None)


####################
# - Handler Registration
####################
def register_handlers(
	blext_pkg: bltyp.BLExtName,
	bl_handlers: BLHandlers,
) -> None:
	"""Register the given Blender handlers."""
	log.info('Registering BLHandlers')  ## TODO: More information
	if _REGISTERED_HANDLERS[blext_pkg] is None:
		bl_handlers.register()
		_REGISTERED_HANDLERS[blext_pkg] = bl_handlers
	else:
		msg = 'There are already BLHandlers registered; they must be unregistered before a new set can be registered.'
		raise ValueError(msg)


def unregister_handlers(blext_pkg: bltyp.BLExtName) -> None:
	"""Unregister this addon's registered Blender handlers."""
	log.info('Unregistering BLHandlers')  ## TODO: More information
	bl_handlers = _REGISTERED_HANDLERS[blext_pkg]

	if bl_handlers is not None:
		bl_handlers.unregister()
		_REGISTERED_HANDLERS[blext_pkg] = None
	else:
		msg = 'There are no BLHandlers registered; therefore, there is nothing to register.'
		raise ValueError(msg)
