# blext
# Copyright (C) 2025 blext Project Contributors
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""A visual DSL for electromagnetic simulation design and analysis implemented as a Blender node editor."""

import functools

import blroots as blr

from . import id_props, operators, panels, preferences

####################
# - Load and Register Addon
####################
BL_REGISTER = blr.gather.classes(id_props, operators, panels)
BL_HANDLERS = blr.gather.handlers(id_props, operators, panels)
BL_KEYMAP_ITEMS = blr.gather.keymap_items(id_props, operators, panels)


####################
# - Registration
####################
register = functools.partial(
	blr.init.register,
	__package__,
	classes_prefs=preferences.BL_REGISTER,
	classes=BL_REGISTER,
	handlers=BL_HANDLERS,
	keymap_items=BL_KEYMAP_ITEMS,
)

unregister = functools.partial(
	blr.init.unregister,
	__package__,
)
